@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -49,7 +49,7 @@
 #include "prefs.h"
 #include "LogFactory.h"
 #include "Logger.h"
-#include "Util.h"
+#include "util.h"
 #include "IntSequence.h"
 #include "DHTGetPeersCommand.h"
 #include "DHTPeerAnnounceStorage.h"
@@ -58,34 +58,33 @@
 #include "BtProgressInfoFile.h"
 #include "BtAnnounce.h"
 #include "BtRuntime.h"
+#include "bittorrent_helper.h"
+#include "BtStopDownloadCommand.h"
 
 namespace aria2 {
 
 BtSetup::BtSetup():_logger(LogFactory::getInstance()) {}
 
 void BtSetup::setup(std::deque<Command*>& commands,
-		    RequestGroup* requestGroup,
-		    DownloadEngine* e,
-		    const Option* option)
+                    RequestGroup* requestGroup,
+                    DownloadEngine* e,
+                    const Option* option)
 {
-  BtContextHandle btContext(dynamic_pointer_cast<BtContext>(requestGroup->getDownloadContext()));
-  if(btContext.isNull()) {
+  if(!requestGroup->getDownloadContext()->hasAttribute(bittorrent::BITTORRENT)){
     return;
   }
-  SharedHandle<BtRegistry> btRegistry = e->getBtRegistry();
-  SharedHandle<PieceStorage> pieceStorage =
-    btRegistry->getPieceStorage(btContext->getInfoHashAsString());
-  SharedHandle<PeerStorage> peerStorage =
-    btRegistry->getPeerStorage(btContext->getInfoHashAsString());
-  SharedHandle<BtRuntime> btRuntime =
-    btRegistry->getBtRuntime(btContext->getInfoHashAsString());
-  SharedHandle<BtAnnounce> btAnnounce =
-    btRegistry->getBtAnnounce(btContext->getInfoHashAsString());
-
+  const BDE& torrentAttrs =
+    requestGroup->getDownloadContext()->getAttribute(bittorrent::BITTORRENT);
+  bool metadataGetMode = !torrentAttrs.containsKey(bittorrent::METADATA);
+  BtObject btObject = e->getBtRegistry()->get(requestGroup->getGID());
+  SharedHandle<PieceStorage> pieceStorage = btObject._pieceStorage;
+  SharedHandle<PeerStorage> peerStorage = btObject._peerStorage;
+  SharedHandle<BtRuntime> btRuntime = btObject._btRuntime;
+  SharedHandle<BtAnnounce> btAnnounce = btObject._btAnnounce;
   // commands
   {
     TrackerWatcherCommand* c =
-      new TrackerWatcherCommand(e->newCUID(), requestGroup, e, btContext);
+      new TrackerWatcherCommand(e->newCUID(), requestGroup, e);
     c->setPeerStorage(peerStorage);
     c->setPieceStorage(pieceStorage);
     c->setBtRuntime(btRuntime);
@@ -93,75 +92,86 @@ void BtSetup::setup(std::deque<Command*>& commands,
     
     commands.push_back(c);
   }
-  {
+  if(!metadataGetMode) {
     PeerChokeCommand* c =
-      new PeerChokeCommand(e->newCUID(), e, btContext);
+      new PeerChokeCommand(e->newCUID(), e);
     c->setPeerStorage(peerStorage);
     c->setBtRuntime(btRuntime);
-
+    
     commands.push_back(c);
   }
   {
     ActivePeerConnectionCommand* c =
-      new ActivePeerConnectionCommand(e->newCUID(), requestGroup, e, btContext,
-				      10);
+      new ActivePeerConnectionCommand(e->newCUID(), requestGroup, e, 10);
     c->setBtRuntime(btRuntime);
     c->setPieceStorage(pieceStorage);
     c->setPeerStorage(peerStorage);
     c->setBtAnnounce(btAnnounce);
-	    
+            
     commands.push_back(c);
   }
 
-  if(!btContext->isPrivate() && DHTSetup::initialized()) {
-    DHTRegistry::_peerAnnounceStorage->addPeerAnnounce(btContext->getInfoHash(),
-						       peerStorage);
+  if((metadataGetMode || torrentAttrs[bittorrent::PRIVATE].i() == 0) &&
+     DHTSetup::initialized()) {
     DHTGetPeersCommand* command =
-      new DHTGetPeersCommand(e->newCUID(), requestGroup, e, btContext);
+      new DHTGetPeersCommand(e->newCUID(), requestGroup, e);
     command->setTaskQueue(DHTRegistry::_taskQueue);
     command->setTaskFactory(DHTRegistry::_taskFactory);
     command->setBtRuntime(btRuntime);
     command->setPeerStorage(peerStorage);
     commands.push_back(command);
   }
-  SharedHandle<UnionSeedCriteria> unionCri(new UnionSeedCriteria());
-  if(option->defined(PREF_SEED_TIME)) {
-    SharedHandle<SeedCriteria> cri(new TimeSeedCriteria(option->getAsInt(PREF_SEED_TIME)*60));
-    unionCri->addSeedCriteria(cri);
-  }
-  {
-    double ratio = option->getAsDouble(PREF_SEED_RATIO);
-    if(ratio > 0.0) {
-      SharedHandle<ShareRatioSeedCriteria> cri
-	(new ShareRatioSeedCriteria(option->getAsDouble(PREF_SEED_RATIO),
-				    btContext));
-      cri->setPieceStorage(pieceStorage);
-      cri->setPeerStorage(peerStorage);
-
+  if(!metadataGetMode) {
+    SharedHandle<UnionSeedCriteria> unionCri(new UnionSeedCriteria());
+    if(option->defined(PREF_SEED_TIME)) {
+      SharedHandle<SeedCriteria> cri
+        (new TimeSeedCriteria(option->getAsInt(PREF_SEED_TIME)*60));
       unionCri->addSeedCriteria(cri);
     }
-  }
-  if(unionCri->getSeedCriterion().size() > 0) {
-    SeedCheckCommand* c =
-      new SeedCheckCommand(e->newCUID(), requestGroup, e, btContext, unionCri);
-    c->setPieceStorage(pieceStorage);
-    c->setBtRuntime(btRuntime);
-    commands.push_back(c);
-  }
+    {
+      double ratio = option->getAsDouble(PREF_SEED_RATIO);
+      if(ratio > 0.0) {
+        SharedHandle<ShareRatioSeedCriteria> cri
+          (new ShareRatioSeedCriteria(option->getAsDouble(PREF_SEED_RATIO),
+                                      requestGroup->getDownloadContext()));
+        cri->setPieceStorage(pieceStorage);
+        cri->setPeerStorage(peerStorage);
 
+        unionCri->addSeedCriteria(cri);
+      }
+    }
+    if(unionCri->getSeedCriterion().size() > 0) {
+      SeedCheckCommand* c =
+        new SeedCheckCommand(e->newCUID(), requestGroup, e, unionCri);
+      c->setPieceStorage(pieceStorage);
+      c->setBtRuntime(btRuntime);
+      commands.push_back(c);
+    }
+  }
   if(PeerListenCommand::getNumInstance() == 0) {
     PeerListenCommand* listenCommand = PeerListenCommand::getInstance(e);
-    IntSequence seq = Util::parseIntRange(option->get(PREF_LISTEN_PORT));
+    IntSequence seq = util::parseIntRange(option->get(PREF_LISTEN_PORT));
     uint16_t port;
     if(listenCommand->bindPort(port, seq)) {
       btRuntime->setListenPort(port);
-      commands.push_back(listenCommand);
+      // Add command to DownloadEngine directly.
+      e->commands.push_back(listenCommand);
     } else {
-      _logger->error(_("Errors occurred while binding port.\n"));
       delete listenCommand;
+      throw DL_ABORT_EX(_("Errors occurred while binding port.\n"));
     }
+  } else {
+    PeerListenCommand* listenCommand = PeerListenCommand::getInstance(e);
+    btRuntime->setListenPort(listenCommand->getPort());
+  }
+  time_t btStopTimeout = option->getAsInt(PREF_BT_STOP_TIMEOUT);
+  if(btStopTimeout > 0) {
+    BtStopDownloadCommand* stopDownloadCommand =
+      new BtStopDownloadCommand(e->newCUID(), requestGroup, e, btStopTimeout);
+    stopDownloadCommand->setBtRuntime(btRuntime);
+    stopDownloadCommand->setPieceStorage(pieceStorage);
+    commands.push_back(stopDownloadCommand);
   }
-
   btRuntime->setReady(true);
 }
 
