@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -52,26 +52,34 @@ private:
   std::string _path;
   std::string _domain;
   bool _secure;
+  time_t _creationTime;
+  time_t _lastAccess;
 public:
   /*
    * If expires = 0 is given, then the cookie becomes session cookie.
+   * domain is normalized using normalizeDomain() function and
+   * assigned to _domain.  If domain is not specified in cookie, call
+   * markOriginServerOnly() after construction.
    */
   Cookie(const std::string& name,
-	 const std::string& value,
-	 time_t  expires,
-	 const std::string& path,
-	 const std::string& domain,
-	 bool secure);
+         const std::string& value,
+         time_t  expires,
+         const std::string& path,
+         const std::string& domain,
+         bool secure);
 
   /*
-   * Creates session cookie. This is equivalent to
-   * Cookie(name, value, 0, path, domain, secure);
+   * Creates session cookie. This is equivalent to Cookie(name, value,
+   * 0, path, domain, secure); domain is normalized using
+   * normalizeDomain() function and assigned to _domain.  If domain is
+   * not specified in cookie, call markOriginServerOnly() after
+   * construction.
    */
   Cookie(const std::string& name,
-	 const std::string& value,
-	 const std::string& path,
-	 const std::string& domain,
-	 bool secure);
+         const std::string& value,
+         const std::string& path,
+         const std::string& domain,
+         bool secure);
 
   Cookie();
 
@@ -82,28 +90,69 @@ public:
   bool good() const;
 
   bool match(const std::string& requestHost, const std::string& requestPath,
-	     time_t date, bool secure) const;
+             time_t date, bool secure) const;
 
   bool validate(const std::string& requestHost,
-		const std::string& requestPath) const;
+                const std::string& requestPath) const;
 
   bool operator==(const Cookie& cookie) const;
 
   bool isExpired() const;
 
-  const std::string& getName() const;
+  const std::string& getName() const
+  {
+    return _name;
+  }
 
-  const std::string& getValue() const;
+  const std::string& getValue() const
+  {
+    return _value;
+  }
 
-  const std::string& getPath() const;
+  const std::string& getPath() const
+  {
+    return _path;
+  }
 
-  const std::string& getDomain() const;
+  const std::string& getDomain() const
+  {
+    return _domain;
+  }
 
-  time_t getExpiry() const;
+  time_t getExpiry() const
+  {
+    return _expiry;
+  }
 
-  bool isSecureCookie() const;
+  bool isSecureCookie() const
+  {
+    return _secure;
+  }
 
-  bool isSessionCookie() const;
+  bool isSessionCookie() const
+  {
+    return _expiry == 0;
+  }
+
+  std::string toNsCookieFormat() const;
+
+  // Makes this Cookie only sent to the origin server.  This function
+  // removes first "." from _domain if _domain starts with ".".
+  void markOriginServerOnly();
+
+  time_t getCreationTime() const
+  {
+    return _creationTime;
+  }
+
+  void updateLastAccess();
+
+  time_t getLastAccess() const
+  {
+    return _lastAccess;
+  }
+
+  static std::string normalizeDomain(const std::string& domain);
 };
 
 typedef std::deque<Cookie> Cookies;
