@@ -55,11 +55,6 @@ const std::string CookieParser::C_PATH("path");
 
 const std::string CookieParser::C_EXPIRES("expires");
 
-Cookie CookieParser::parse(const std::string& cookieStr) const
-{
-  return parse(cookieStr, A2STR::NIL, A2STR::NIL);
-}
-
 Cookie CookieParser::parse(const std::string& cookieStr, const std::string& defaultDomain, const std::string& defaultPath) const
 {
   std::vector<std::string> terms;
@@ -71,43 +66,38 @@ Cookie CookieParser::parse(const std::string& cookieStr, const std::string& defa
   util::split(nameValue, terms.front(), '=');
 
   std::map<std::string, std::string> values;
-  values[C_DOMAIN] = defaultDomain;
-  values[C_PATH] = defaultPath;
-  
   for(std::vector<std::string>::iterator itr = terms.begin()+1;
       itr != terms.end(); ++itr) {
     std::pair<std::string, std::string> nv;
     util::split(nv, *itr, '=');
     values[nv.first] = nv.second;
   }
+  bool useDefaultDomain = false;
+  std::map<std::string, std::string>::iterator mitr;
+  mitr = values.find(C_DOMAIN);
+  if(mitr == values.end() || (*mitr).second.empty()) {
+    useDefaultDomain = true;
+    values[C_DOMAIN] = defaultDomain;
+  }
+  mitr = values.find(C_PATH);
+  if(mitr == values.end() || (*mitr).second.empty()) {
+    values[C_PATH] = defaultPath;
+  }
   time_t expiry = 0;
-  if(values.find(C_EXPIRES) != values.end()) {
+  if(values.count(C_EXPIRES)) {
     Time expiryTime = Time::parseHTTPDate(values[C_EXPIRES]);
     if(expiryTime.good()) {
       expiry = expiryTime.getTime();
     }
   }
-  return Cookie(nameValue.first, nameValue.second,
+  Cookie cookie(nameValue.first, nameValue.second,
                 expiry,
                 values[C_PATH], values[C_DOMAIN],
                 values.find(C_SECURE) != values.end());
-}
-
-
-Cookies CookieParser::parse(std::istream& s) const
-{
-  Cookies cookies;
-  std::string line;
-  while(getline(s, line)) {
-    if(util::trim(line).empty() || util::startsWith(line, A2STR::SHARP_C)) {
-      continue;
-    }
-    Cookie cookie = parse(line);
-    if(cookie.good()) {
-      cookies.push_back(cookie);
-    }
+  if(useDefaultDomain) {
+    cookie.markOriginServerOnly();
   }
-  return cookies;
+  return cookie;
 }
 
 } // namespace aria2
