@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,12 +36,12 @@
 #include "LogFactory.h"
 #include "Logger.h"
 #include "PeerListProcessor.h"
-#include "Util.h"
+#include "util.h"
 #include "prefs.h"
 #include "DlAbortEx.h"
 #include "message.h"
 #include "SimpleRandomizer.h"
-#include "BtContext.h"
+#include "DownloadContext.h"
 #include "PieceStorage.h"
 #include "BtRuntime.h"
 #include "PeerStorage.h"
@@ -51,52 +51,48 @@
 #include "A2STR.h"
 #include "Request.h"
 #include "bencode.h"
+#include "bittorrent_helper.h"
 
 namespace aria2 {
 
-DefaultBtAnnounce::DefaultBtAnnounce(const BtContextHandle& btContext,
-				     const Option* option):
-  btContext(btContext),
+DefaultBtAnnounce::DefaultBtAnnounce
+(const SharedHandle<DownloadContext>& downloadContext,
+ const Option* option):
+  _downloadContext(downloadContext),
   trackers(0),
   interval(DEFAULT_ANNOUNCE_INTERVAL),
   minInterval(DEFAULT_ANNOUNCE_INTERVAL),
   _userDefinedInterval(0),
   complete(0),
   incomplete(0),
-  announceList(btContext->getAnnounceTiers()),
+  announceList(downloadContext->getAttribute(bittorrent::BITTORRENT)[bittorrent::ANNOUNCE_LIST]),
   option(option),
   logger(LogFactory::getInstance()),
   _randomizer(SimpleRandomizer::getInstance())
 {
   prevAnnounceTime.setTimeInSec(0);
-  generateKey();
 }
 
 DefaultBtAnnounce::~DefaultBtAnnounce() {
 }
 
-void DefaultBtAnnounce::generateKey()
-{
-  key = Util::randomAlpha(8, _randomizer);
-}
-
 bool DefaultBtAnnounce::isDefaultAnnounceReady() {
   return (trackers == 0 &&
-	  prevAnnounceTime.elapsed(_userDefinedInterval==0?
-				   minInterval:_userDefinedInterval) &&
-	  !announceList.allTiersFailed());
+          prevAnnounceTime.elapsed(_userDefinedInterval==0?
+                                   minInterval:_userDefinedInterval) &&
+          !announceList.allTiersFailed());
 }
 
 bool DefaultBtAnnounce::isStoppedAnnounceReady() {
   return (trackers == 0 &&
-	  btRuntime->isHalt() &&
-	  announceList.countStoppedAllowedTier());
+          btRuntime->isHalt() &&
+          announceList.countStoppedAllowedTier());
 }
 
 bool DefaultBtAnnounce::isCompletedAnnounceReady() {
   return (trackers == 0 &&
-	  pieceStorage->allDownloadFinished() &&
-	  announceList.countCompletedAllowedTier());
+          pieceStorage->allDownloadFinished() &&
+          announceList.countCompletedAllowedTier());
 }
 
 bool DefaultBtAnnounce::isAnnounceReady() {
@@ -145,25 +141,28 @@ std::string DefaultBtAnnounce::getAnnounceUrl() {
   std::string url = announceList.getAnnounce();
   url += uriHasQuery(url) ? "&" : "?";
   url += "info_hash=";
-  url += Util::torrentUrlencode(btContext->getInfoHash(),
-				btContext->getInfoHashLength());
+  url += util::torrentUrlencode(bittorrent::getInfoHash(_downloadContext),
+                                INFO_HASH_LENGTH);
   url += "&peer_id=";
-  url += Util::torrentUrlencode(btContext->getPeerId(), 20);
+  url += util::torrentUrlencode(bittorrent::getStaticPeerId(), PEER_ID_LENGTH);
   url += "&uploaded=";
-  url += Util::uitos(stat.getSessionUploadLength());
+  url += util::uitos(stat.getSessionUploadLength());
   url += "&downloaded=";
-  url += Util::uitos(stat.getSessionDownloadLength());
+  url += util::uitos(stat.getSessionDownloadLength());
   url += "&left=";
-  url += Util::uitos(left);
+  url += util::uitos(left);
   url += "&compact=1";
   url += "&key=";
-  url += key;
+  // Use last 8 bytes of peer ID as a key
+  size_t keyLen = 8;
+  url += util::torrentUrlencode
+    (bittorrent::getStaticPeerId()+PEER_ID_LENGTH-keyLen, keyLen);
   url += "&numwant=";
-  url += Util::uitos(numWant);
+  url += util::uitos(numWant);
   url += "&no_peer_id=1";
   if(btRuntime->getListenPort() > 0) {
     url += "&port=";
-    url += Util::uitos(btRuntime->getListenPort());
+    url += util::uitos(btRuntime->getListenPort());
   }
   std::string event = announceList.getEventString();
   if(!event.empty()) {
@@ -171,7 +170,7 @@ std::string DefaultBtAnnounce::getAnnounceUrl() {
     url += event;
   }
   if(!trackerId.empty()) {
-    url += "&trackerid="+Util::torrentUrlencode(trackerId);
+    url += "&trackerid="+util::torrentUrlencode(trackerId);
   }
   if(option->getAsBool(PREF_BT_REQUIRE_CRYPTO)) {
     url += "&requirecrypto=1";
@@ -210,9 +209,11 @@ void DefaultBtAnnounce::resetAnnounce() {
 
 void
 DefaultBtAnnounce::processAnnounceResponse(const unsigned char* trackerResponse,
-					   size_t trackerResponseLength)
+                                           size_t trackerResponseLength)
 {
-  logger->debug("Now processing tracker response.");
+  if(logger->debug()) {
+    logger->debug("Now processing tracker response.");
+  }
   const BDE dict =
     bencode::decode(trackerResponse, trackerResponseLength);
   if(!dict.isDict()) {
@@ -230,17 +231,23 @@ DefaultBtAnnounce::processAnnounceResponse(const unsigned char* trackerResponse,
   const BDE& tid = dict[BtAnnounce::TRACKER_ID];
   if(tid.isString()) {
     trackerId = tid.s();
-    logger->debug("Tracker ID:%s", trackerId.c_str());
+    if(logger->debug()) {
+      logger->debug("Tracker ID:%s", trackerId.c_str());
+    }
   }
   const BDE& ival = dict[BtAnnounce::INTERVAL];
   if(ival.isInteger() && ival.i() > 0) {
     interval = ival.i();
-    logger->debug("Interval:%d", interval);
+    if(logger->debug()) {
+      logger->debug("Interval:%d", interval);
+    }
   }
   const BDE& mival = dict[BtAnnounce::MIN_INTERVAL];
   if(mival.isInteger() && mival.i() > 0) {
     minInterval = mival.i();
-    logger->debug("Min interval:%d", minInterval);
+    if(logger->debug()) {
+      logger->debug("Min interval:%d", minInterval);
+    }
     if(minInterval > interval) {
       minInterval = interval;
     }
@@ -251,12 +258,16 @@ DefaultBtAnnounce::processAnnounceResponse(const unsigned char* trackerResponse,
   const BDE& comp = dict[BtAnnounce::COMPLETE];
   if(comp.isInteger()) {
     complete = comp.i();
-    logger->debug("Complete:%d", complete);
+    if(logger->debug()) {
+      logger->debug("Complete:%d", complete);
+    }
   }
   const BDE& incomp = dict[BtAnnounce::INCOMPLETE];
   if(incomp.isInteger()) {
     incomplete = incomp.i();
-    logger->debug("Incomplete:%d", incomplete);
+    if(logger->debug()) {
+      logger->debug("Incomplete:%d", incomplete);
+    }
   }
   const BDE& peerData = dict[BtAnnounce::PEERS];
   if(peerData.isNone()) {
@@ -272,8 +283,8 @@ DefaultBtAnnounce::processAnnounceResponse(const unsigned char* trackerResponse,
 
 bool DefaultBtAnnounce::noMoreAnnounce() {
   return (trackers == 0 &&
-	  btRuntime->isHalt() &&
-	  !announceList.countStoppedAllowedTier());
+          btRuntime->isHalt() &&
+          !announceList.countStoppedAllowedTier());
 }
 
 void DefaultBtAnnounce::shuffleAnnounce() {
