@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -40,13 +40,13 @@
 #include "Logger.h"
 #include "Piece.h"
 #include "Peer.h"
-#include "BtContext.h"
 #include "PieceStorage.h"
 #include "BtMessageDispatcher.h"
 #include "BtMessageFactory.h"
 #include "BtMessage.h"
 #include "a2functional.h"
 #include "SimpleRandomizer.h"
+#include "array_fun.h"
 
 namespace aria2 {
 
@@ -54,12 +54,16 @@ DefaultBtRequestFactory::DefaultBtRequestFactory():
   cuid(0),
   _logger(LogFactory::getInstance())
 {
-  LogFactory::getInstance()->debug("DefaultBtRequestFactory::instantiated");
+  if(_logger->debug()) {
+    _logger->debug("DefaultBtRequestFactory::instantiated");
+  }
 }
 
 DefaultBtRequestFactory::~DefaultBtRequestFactory()
 {
-  LogFactory::getInstance()->debug("DefaultBtRequestFactory::deleted");
+  if(_logger->debug()) {
+    _logger->debug("DefaultBtRequestFactory::deleted");
+  }
 }
 
 void DefaultBtRequestFactory::addTargetPiece(const PieceHandle& piece)
@@ -85,15 +89,15 @@ public:
 
 void DefaultBtRequestFactory::removeCompletedPiece() {
   std::for_each(pieces.begin(), pieces.end(),
-		AbortCompletedPieceRequest(dispatcher));
+                AbortCompletedPieceRequest(dispatcher));
   pieces.erase(std::remove_if(pieces.begin(), pieces.end(),
-			      mem_fun_sh(&Piece::pieceComplete)),
-	       pieces.end());
+                              mem_fun_sh(&Piece::pieceComplete)),
+               pieces.end());
 }
 
 void DefaultBtRequestFactory::removeTargetPiece(const PieceHandle& piece) {
   pieces.erase(std::remove(pieces.begin(), pieces.end(), piece),
-	       pieces.end());
+               pieces.end());
   dispatcher->doAbortOutstandingRequestAction(piece);
   _pieceStorage->cancelPiece(piece);
 }
@@ -104,7 +108,7 @@ private:
   WeakHandle<PieceStorage> _pieceStorage;
 public:
   ProcessChokedPiece(const SharedHandle<Peer>& peer,
-		     const WeakHandle<PieceStorage>& pieceStorage):
+                     const WeakHandle<PieceStorage>& pieceStorage):
     _peer(peer),
     _pieceStorage(pieceStorage) {}
 
@@ -131,10 +135,10 @@ public:
 void DefaultBtRequestFactory::doChokedAction()
 {
   std::for_each(pieces.begin(), pieces.end(),
-		ProcessChokedPiece(peer, _pieceStorage));
+                ProcessChokedPiece(peer, _pieceStorage));
   pieces.erase(std::remove_if(pieces.begin(), pieces.end(),
-			      FindChokedPiece(peer)),
-	       pieces.end());
+                              FindChokedPiece(peer)),
+               pieces.end());
 }
 
 void DefaultBtRequestFactory::removeAllTargetPiece() {
@@ -148,18 +152,30 @@ void DefaultBtRequestFactory::removeAllTargetPiece() {
 void DefaultBtRequestFactory::createRequestMessages
 (std::deque<SharedHandle<BtMessage> >& requests, size_t max)
 {
+  if(requests.size() >= max) {
+    return;
+  }
+  size_t getnum = max-requests.size();
+  std::vector<size_t> blockIndexes;
+  blockIndexes.reserve(getnum);
   for(Pieces::iterator itr = pieces.begin();
-      itr != pieces.end() && requests.size() < max; ++itr) {
-    PieceHandle& piece = *itr;
-    size_t blockIndex;
-    while(requests.size() < max &&
-	  piece->getMissingUnusedBlockIndex(blockIndex)) {
-      _logger->debug("Creating RequestMessage index=%u, begin=%u, blockIndex=%u",
-		    piece->getIndex(),
-		    blockIndex*piece->getBlockLength(),
-		    blockIndex);
-
-      requests.push_back(messageFactory->createRequestMessage(piece, blockIndex));
+      itr != pieces.end() && getnum; ++itr) {
+    SharedHandle<Piece>& piece = *itr;
+    if(piece->getMissingUnusedBlockIndex(blockIndexes, getnum)) {
+      getnum -= blockIndexes.size();
+      for(std::vector<size_t>::const_iterator i = blockIndexes.begin();
+          i != blockIndexes.end(); ++i) {
+        if(_logger->debug()) {
+          _logger->debug("Creating RequestMessage index=%u, begin=%u,"
+                         " blockIndex=%u",
+                         piece->getIndex(),
+                         (*i)*piece->getBlockLength(),
+                         (*i));
+        }
+        requests.push_back
+          (messageFactory->createRequestMessage(piece, *i));
+      }
+      blockIndexes.clear();
     }
   }
 }
@@ -170,20 +186,37 @@ void DefaultBtRequestFactory::createRequestMessagesOnEndGame
   for(Pieces::iterator itr = pieces.begin();
       itr != pieces.end() && requests.size() < max; ++itr) {
     PieceHandle& piece = *itr;
+    const size_t mislen = piece->getBitfieldLength();
+    array_ptr<unsigned char> misbitfield(new unsigned char[mislen]);
+
+    piece->getAllMissingBlockIndexes(misbitfield, mislen);
+
     std::deque<size_t> missingBlockIndexes;
-    piece->getAllMissingBlockIndexes(missingBlockIndexes);
+    size_t blockIndex = 0;
+    for(size_t i = 0; i < mislen; ++i) {
+      unsigned char bits = misbitfield[i];
+      unsigned char mask = 128;
+      for(size_t bi = 0; bi < 8; ++bi, mask >>= 1, ++blockIndex) {
+        if(bits & mask) {
+          missingBlockIndexes.push_back(blockIndex);
+        }
+      }
+    }
     std::random_shuffle(missingBlockIndexes.begin(), missingBlockIndexes.end(),
-			*(SimpleRandomizer::getInstance().get()));
+                        *(SimpleRandomizer::getInstance().get()));
     for(std::deque<size_t>::const_iterator bitr = missingBlockIndexes.begin();
-	bitr != missingBlockIndexes.end() && requests.size() < max; bitr++) {
-      size_t blockIndex = *bitr;
+        bitr != missingBlockIndexes.end() && requests.size() < max; bitr++) {
+      const size_t& blockIndex = *bitr;
       if(!dispatcher->isOutstandingRequest(piece->getIndex(),
-					   blockIndex)) {
-      _logger->debug("Creating RequestMessage index=%u, begin=%u, blockIndex=%u",
-		    piece->getIndex(),
-		    blockIndex*piece->getBlockLength(),
-		    blockIndex);
-	requests.push_back(messageFactory->createRequestMessage(piece, blockIndex));
+                                           blockIndex)) {
+        if(_logger->debug()) {
+          _logger->debug("Creating RequestMessage index=%u, begin=%u,"
+                         " blockIndex=%u",
+                         piece->getIndex(),
+                         blockIndex*piece->getBlockLength(),
+                         blockIndex);
+        }
+        requests.push_back(messageFactory->createRequestMessage(piece, blockIndex));
       }
     }
   }
@@ -210,24 +243,14 @@ public:
 size_t DefaultBtRequestFactory::countMissingBlock()
 {
   return std::for_each(pieces.begin(), pieces.end(),
-		       CountMissingBlock()).getNumMissingBlock();
+                       CountMissingBlock()).getNumMissingBlock();
 }
 
 void DefaultBtRequestFactory::getTargetPieceIndexes
 (std::deque<size_t>& indexes) const
 {
   std::transform(pieces.begin(), pieces.end(), std::back_inserter(indexes),
-		 mem_fun_sh(&Piece::getIndex));
-}
-
-std::deque<SharedHandle<Piece> >& DefaultBtRequestFactory::getTargetPieces()
-{
-  return pieces;
-}
-
-void DefaultBtRequestFactory::setBtContext(const SharedHandle<BtContext>& btContext)
-{
-  this->btContext = btContext;
+                 mem_fun_sh(&Piece::getIndex));
 }
 
 void DefaultBtRequestFactory::setPieceStorage
