@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -43,6 +43,8 @@
 #include "util.h"
 #include "DownloadEngine.h"
 #include "DownloadContext.h"
+#include "a2functional.h"
+#include "RecoverableException.h"
 
 namespace aria2 {
 
@@ -59,13 +61,20 @@ bool FileAllocationCommand::executeInternal()
   }
   _fileAllocationEntry->allocateChunk();
   if(_fileAllocationEntry->finished()) {
-    logger->debug(MSG_ALLOCATION_COMPLETED,
-		  _timer.difference(),
-		  util::itos(_requestGroup->getTotalLength(), true).c_str());
+    if(logger->debug()) {
+      logger->debug(MSG_ALLOCATION_COMPLETED,
+                    _timer.difference(),
+                    util::itos(_requestGroup->getTotalLength(), true).c_str());
+    }
     _e->_fileAllocationMan->dropPickedEntry();
     
     std::deque<Command*> commands;
-    _fileAllocationEntry->prepareForNextAction(commands, _e);
+    try {
+      _fileAllocationEntry->prepareForNextAction(commands, _e);
+    } catch(RecoverableException& e) {
+      std::for_each(commands.begin(), commands.end(), Deleter());
+      throw;
+    }
     _e->addCommand(commands);
     _e->setNoWait(true);
     return true;
@@ -80,7 +89,7 @@ bool FileAllocationCommand::handleException(Exception& e)
   _e->_fileAllocationMan->dropPickedEntry();
   logger->error(MSG_FILE_ALLOCATION_FAILURE, e, cuid);
   logger->error(MSG_DOWNLOAD_NOT_COMPLETE, cuid,
-		_requestGroup->getDownloadContext()->getBasePath().c_str());
+                _requestGroup->getDownloadContext()->getBasePath().c_str());
   return true;
 }
 
