@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -43,18 +43,20 @@
 #include "FtpFinishDownloadCommand.h"
 #include "FtpConnection.h"
 #include "Logger.h"
+#include "DownloadContext.h"
 
 namespace aria2 {
 
 FtpDownloadCommand::FtpDownloadCommand
 (int cuid,
  const RequestHandle& req,
+ const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
  const SharedHandle<FtpConnection>& ftpConnection,
  DownloadEngine* e,
  const SocketHandle& dataSocket,
  const SocketHandle& ctrlSocket)
-  :DownloadCommand(cuid, req, requestGroup, e, dataSocket),
+  :DownloadCommand(cuid, req, fileEntry, requestGroup, e, dataSocket),
    _ftpConnection(ftpConnection),
    ctrlSocket(ctrlSocket) {}
 
@@ -64,8 +66,9 @@ FtpDownloadCommand::~FtpDownloadCommand() {}
 bool FtpDownloadCommand::prepareForNextSegment()
 {
   if(getOption()->getAsBool(PREF_FTP_REUSE_CONNECTION) &&
-     (uint64_t)_segments.front()->getPositionToWrite() == _requestGroup->getTotalLength()) {
-    Command* command = new FtpFinishDownloadCommand(cuid, req, _requestGroup, _ftpConnection, e, ctrlSocket);
+     static_cast<uint64_t>(_fileEntry->gtoloff(_segments.front()->getPositionToWrite())) == _fileEntry->getLength()) {
+    Command* command = new FtpFinishDownloadCommand
+      (cuid, req, _fileEntry, _requestGroup, _ftpConnection, e, ctrlSocket);
     e->commands.push_back(command);
 
     if(_requestGroup->downloadFinished()) {
