@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,56 +35,62 @@
 #ifndef _D_HTTP_CONNECTION_H_
 #define _D_HTTP_CONNECTION_H_
 
-#include "Segment.h"
-#include "Socket.h"
-#include "Request.h"
-#include "Option.h"
-#include "Logger.h"
 #include "common.h"
-#include "Logger.h"
-#include "HttpResponse.h"
-#include "HttpHeaderProcessor.h"
+
+#include <string>
+#include <deque>
+
+#include "SharedHandle.h"
+#include "SocketBuffer.h"
+
+namespace aria2 {
+
+class HttpRequest;
+class HttpResponse;
+class HttpHeaderProcessor;
+class Option;
+class Logger;
+class Segment;
+class SocketCore;
 
 class HttpRequestEntry {
 private:
-  HttpRequestHandle _httpRequest;
-  HttpHeaderProcessorHandle _proc;
+  SharedHandle<HttpRequest> _httpRequest;
+  SharedHandle<HttpHeaderProcessor> _proc;
 public:
-  HttpRequestEntry(const HttpRequestHandle& httpRequest,
-		   const HttpHeaderProcessorHandle& proc):
-    _httpRequest(httpRequest),
-    _proc(proc) {}
+  HttpRequestEntry(const SharedHandle<HttpRequest>& httpRequest);
 
-  ~HttpRequestEntry() {}
+  ~HttpRequestEntry();
 
-  HttpRequestHandle getHttpRequest() const
+  const SharedHandle<HttpRequest>& getHttpRequest() const
   {
     return _httpRequest;
   }
 
-  HttpHeaderProcessorHandle getHttpHeaderProcessor() const
+  const SharedHandle<HttpHeaderProcessor>& getHttpHeaderProcessor() const
   {
     return _proc;
   }
 };
 
 typedef SharedHandle<HttpRequestEntry> HttpRequestEntryHandle;
-typedef deque<HttpRequestEntryHandle> HttpRequestEntries;
+typedef std::deque<HttpRequestEntryHandle> HttpRequestEntries;
 
 class HttpConnection {
 private:
   int32_t cuid;
-  SocketHandle socket;
+  SharedHandle<SocketCore> socket;
+  SocketBuffer _socketBuffer;
   const Option* option;
-  const Logger* logger;
+  Logger* logger;
 
   HttpRequestEntries outstandingHttpRequests;
 
-  string eraseConfidentialInfo(const string& request);
+  std::string eraseConfidentialInfo(const std::string& request);
 public:
   HttpConnection(int32_t cuid,
-		 const SocketHandle& socket,
-		 const Option* op);
+                 const SharedHandle<SocketCore>& socket,
+                 const Option* op);
 
   /**
    * Sends Http request.
@@ -93,12 +99,12 @@ public:
    * HTTP proxy(GET method).
    * @param segment indicates starting postion of the file for downloading
    */
-  void sendRequest(const HttpRequestHandle& httpRequest);
+  void sendRequest(const SharedHandle<HttpRequest>& httpRequest);
 
   /**
    * Sends Http proxy request using CONNECT method.
    */
-  void sendProxyRequest(const HttpRequestHandle& httpRequest);
+  void sendProxyRequest(const SharedHandle<HttpRequest>& httpRequest);
 
   /**
    * Receives HTTP response from the server and returns HttpResponseHandle
@@ -111,20 +117,19 @@ public:
    * 
    * @return HttpResponse or 0 if whole response header is not received
    */
-  HttpResponseHandle receiveResponse();
+  SharedHandle<HttpResponse> receiveResponse();
 
-  HttpRequestHandle getFirstHttpRequest() const
-  {
-    if(outstandingHttpRequests.size() > 0) {
-      return outstandingHttpRequests.front()->getHttpRequest();
-    } else {
-      return 0;
-    }
-  }
+  SharedHandle<HttpRequest> getFirstHttpRequest() const;
 
-  bool isIssued(const SegmentHandle& segment) const;
+  bool isIssued(const SharedHandle<Segment>& segment) const;
+
+  bool sendBufferIsEmpty() const;
+
+  void sendPendingData();
 };
 
 typedef SharedHandle<HttpConnection> HttpConnectionHandle;
 
+} // namespace aria2
+
 #endif // _D_HTTP_CONNECTION_H_
