@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -41,6 +41,9 @@
 #include "HttpServerCommand.h"
 #include "CUIDCounter.h"
 #include "RequestGroupMan.h"
+#include "FileEntry.h"
+#include "prefs.h"
+#include "Option.h"
 
 namespace aria2 {
 
@@ -68,16 +71,17 @@ bool HttpListenCommand::execute()
       socket->getPeerInfo(peerInfo);
 
       logger->info("XML-RPC: Accepted the connection from %s:%u.",
-		   peerInfo.first.c_str(), peerInfo.second);
+                   peerInfo.first.c_str(), peerInfo.second);
 
       HttpServerCommand* c =
-	new HttpServerCommand(_e->newCUID(), _e, socket);
-      c->setStatus(Command::STATUS_ONESHOT_REALTIME);
+        new HttpServerCommand(_e->newCUID(), _e, socket);
       _e->setNoWait(true);
       _e->commands.push_back(c);
     }
   } catch(RecoverableException& e) {
-    logger->debug(MSG_ACCEPT_FAILURE, _e, cuid);
+    if(logger->debug()) {
+      logger->debug(MSG_ACCEPT_FAILURE, _e, cuid);
+    }
   }
   _e->commands.push_back(this);
   return false;
@@ -91,7 +95,11 @@ bool HttpListenCommand::bindPort(uint16_t port)
   _serverSocket.reset(new SocketCore());
   logger->info("CUID#%d - Setting up HttpListenCommand", cuid);
   try {
-    _serverSocket->bind(port);
+    int flags = 0;
+    if(_e->option->getAsBool(PREF_XML_RPC_LISTEN_ALL)) {
+      flags = AI_PASSIVE;
+    }
+    _serverSocket->bind(port, flags);
     _serverSocket->beginListen();
     _serverSocket->setNonBlockingMode();
     logger->info(MSG_LISTENING_PORT, cuid, port);
