@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,20 +35,56 @@
 #include "InitiateConnectionCommandFactory.h"
 #include "HttpInitiateConnectionCommand.h"
 #include "FtpInitiateConnectionCommand.h"
+#include "Request.h"
+#include "RequestGroup.h"
+#include "DownloadEngine.h"
 #include "DlAbortEx.h"
+#include "StringFormat.h"
+#include "Option.h"
+#include "prefs.h"
+#include "SocketCore.h"
+#include "DownloadContext.h"
 
-Command* InitiateConnectionCommandFactory::createInitiateConnectionCommand(int cuid, const RequestHandle req, RequestGroup* requestGroup, DownloadEngine* e) {
-  if(req->getProtocol() == "http"
+namespace aria2 {
+
+Command*
+InitiateConnectionCommandFactory::createInitiateConnectionCommand
+(int32_t cuid,
+ const RequestHandle& req,
+ const SharedHandle<FileEntry>& fileEntry,
+ RequestGroup* requestGroup,
+ DownloadEngine* e)
+{
+  if(req->getProtocol() == Request::PROTO_HTTP
 #ifdef ENABLE_SSL
      // for SSL
-     || req->getProtocol() == "https"
+     || req->getProtocol() == Request::PROTO_HTTPS
 #endif // ENABLE_SSL
      ) {
-    return new HttpInitiateConnectionCommand(cuid, req, requestGroup, e);
-  } else if(req->getProtocol() == "ftp") {
-    return new FtpInitiateConnectionCommand(cuid, req, requestGroup, e);
+    
+    if(requestGroup->getOption()->getAsBool(PREF_ENABLE_HTTP_KEEP_ALIVE)) {
+      req->setKeepAliveHint(true);
+    }
+    if(requestGroup->getOption()->getAsBool(PREF_ENABLE_HTTP_PIPELINING)) {
+      req->setPipeliningHint(true);
+    }
+
+    return
+      new HttpInitiateConnectionCommand(cuid, req, fileEntry, requestGroup, e);
+  } else if(req->getProtocol() == Request::PROTO_FTP) {
+    if(req->getFile().empty()) {
+      throw DL_ABORT_EX
+        (StringFormat("FTP URL %s doesn't contain file path.",
+                      req->getUrl().c_str()).str());
+    }
+    return
+      new FtpInitiateConnectionCommand(cuid, req, fileEntry, requestGroup, e);
   } else {
     // these protocols are not supported yet
-    throw new DlAbortEx("%s is not supported yet.", req->getProtocol().c_str());
+    throw DL_ABORT_EX
+      (StringFormat("%s is not supported yet.",
+                    req->getProtocol().c_str()).str());
   }
 }
+
+} // namespace aria2
