@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,23 +36,21 @@
 #define _D_MULTI_FILE_ALLOCATION_ITERATOR_H_
 
 #include "FileAllocationIterator.h"
+#include <deque>
+
+namespace aria2 {
 
 class MultiDiskAdaptor;
 class DiskWriterEntry;
-typedef SharedHandle<DiskWriterEntry> DiskWriterEntryHandle;
-typedef deque<DiskWriterEntryHandle> DiskWriterEntries;
-class SingleFileAllocationIterator;
-typedef SharedHandle<SingleFileAllocationIterator> SingleFileAllocationIteratorHandle;
 
 class MultiFileAllocationIterator:public FileAllocationIterator
 {
 private:
   MultiDiskAdaptor* _diskAdaptor;
-  DiskWriterEntries _entries;
-  SingleFileAllocationIteratorHandle _fileAllocationIterator;
-  int64_t _offset;
+  std::deque<SharedHandle<DiskWriterEntry> > _entries;
+  SharedHandle<FileAllocationIterator> _fileAllocationIterator;
+  off_t _offset;
 
-  DiskWriterEntries makeDiskWriterEntries(const DiskWriterEntries& srcEntries, int32_t pieceLength) const;
 public:
   MultiFileAllocationIterator(MultiDiskAdaptor* diskAdaptor);
 
@@ -62,13 +60,15 @@ public:
   
   virtual bool finished();
 
-  virtual int64_t getCurrentLength();
+  virtual off_t getCurrentLength();
 
-  virtual int64_t getTotalLength();
+  virtual uint64_t getTotalLength();
 
-  const DiskWriterEntries& getDiskWriterEntries() const;
+  const std::deque<SharedHandle<DiskWriterEntry> >& getDiskWriterEntries() const;
 };
 
 typedef SharedHandle<MultiFileAllocationIterator> MultiFileAllocationIteratorHandle;
 
+} // namespace aria2
+
 #endif // _D_MULTI_FILE_ALLOCATION_ITERATOR_H_
