@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -47,22 +47,21 @@
 namespace aria2 {
 
 PeerAbstractCommand::PeerAbstractCommand(int32_t cuid,
-					 const PeerHandle& peer,
-					 DownloadEngine* e,
-					 const SocketHandle& s):
+                                         const PeerHandle& peer,
+                                         DownloadEngine* e,
+                                         const SocketHandle& s):
   Command(cuid),
   e(e),
   socket(s),
   peer(peer),
   checkSocketIsReadable(false),
   checkSocketIsWritable(false),
-  uploadLimitCheck(false),
-  uploadLimit(0),
   noCheck(false)
 {
   if(!socket.isNull() && socket->isOpen()) {
     setReadCheckSocket(socket);
   }
+  // TODO referring global option
   timeout = e->option->getAsInt(PREF_BT_TIMEOUT);
 }
 
@@ -74,9 +73,12 @@ PeerAbstractCommand::~PeerAbstractCommand()
 
 bool PeerAbstractCommand::execute()
 {
-  logger->debug("CUID#%d -"
-		" socket: read:%d, write:%d, hup:%d, err:%d, noCheck:%d",
-		cuid, _readEvent, _writeEvent, _hupEvent, _errorEvent, noCheck);
+  if(logger->debug()) {
+    logger->debug("CUID#%d -"
+                  " socket: read:%d, write:%d, hup:%d, err:%d, noCheck:%d",
+                  cuid, _readEvent, _writeEvent, _hupEvent, _errorEvent,
+                  noCheck);
+  }
   if(exitBeforeExecute()) {
     onAbort();
     return true;
@@ -88,12 +90,12 @@ bool PeerAbstractCommand::execute()
        _hupEvent) {
       checkPoint.reset();
     } else if(_errorEvent) {
-      throw DlAbortEx
-	(StringFormat(MSG_NETWORK_PROBLEM,
-		      socket->getSocketError().c_str()).str());
+      throw DL_ABORT_EX
+        (StringFormat(MSG_NETWORK_PROBLEM,
+                      socket->getSocketError().c_str()).str());
     }
     if(checkPoint.elapsed(timeout)) {
-      throw DlAbortEx(EX_TIME_OUT);
+      throw DL_ABORT_EX(EX_TIME_OUT);
     }
     return executeInternal();
   } catch(DownloadFailureException& err) {
@@ -102,9 +104,11 @@ bool PeerAbstractCommand::execute()
     onFailure();
     return true;
   } catch(RecoverableException& err) {
-    logger->debug(MSG_TORRENT_DOWNLOAD_ABORTED, err, cuid);
-    logger->debug(MSG_PEER_BANNED,
-		  cuid, peer->ipaddr.c_str(), peer->port);
+    if(logger->debug()) {
+      logger->debug(MSG_TORRENT_DOWNLOAD_ABORTED, err, cuid);
+      logger->debug(MSG_PEER_BANNED,
+                    cuid, peer->ipaddr.c_str(), peer->port);
+    }
     onAbort();
     return prepareForNextPeer(0);
   }
@@ -132,9 +136,9 @@ void PeerAbstractCommand::setReadCheckSocket(const SocketHandle& socket)
   } else {
     if(checkSocketIsReadable) {
       if(readCheckTarget != socket) {
-	e->deleteSocketForReadCheck(readCheckTarget, this);
-	e->addSocketForReadCheck(socket, this);
-	readCheckTarget = socket;
+        e->deleteSocketForReadCheck(readCheckTarget, this);
+        e->addSocketForReadCheck(socket, this);
+        readCheckTarget = socket;
       }
     } else {
       e->addSocketForReadCheck(socket, this);
@@ -160,9 +164,9 @@ void PeerAbstractCommand::setWriteCheckSocket(const SocketHandle& socket)
   } else {
     if(checkSocketIsWritable) {
       if(writeCheckTarget != socket) {
-	e->deleteSocketForWriteCheck(writeCheckTarget, this);
-	e->addSocketForWriteCheck(socket, this);
-	writeCheckTarget = socket;
+        e->deleteSocketForWriteCheck(writeCheckTarget, this);
+        e->addSocketForWriteCheck(socket, this);
+        writeCheckTarget = socket;
       }
     } else {
       e->addSocketForWriteCheck(socket, this);
@@ -172,16 +176,6 @@ void PeerAbstractCommand::setWriteCheckSocket(const SocketHandle& socket)
   }
 }
 
-void PeerAbstractCommand::setUploadLimit(unsigned int uploadLimit)
-{
-  this->uploadLimit = uploadLimit;
-}
-
-void PeerAbstractCommand::setUploadLimitCheck(bool check)
-{
-  this->uploadLimitCheck = check;
-}
-
 void PeerAbstractCommand::setNoCheck(bool check)
 {
   this->noCheck = check;
