@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,29 +37,67 @@
 
 #include "common.h"
 
-#include <deque>
+#include <cstring>
 
-#include "SharedHandle.h"
+#include "a2netcompat.h"
+#include "bencode.h"
+#include "Peer.h"
 
 namespace aria2 {
 
-class Peer;
-namespace bencode {
-class BDE;
-}
-
 class PeerListProcessor {
 public:
-  virtual ~PeerListProcessor() {}
+  template<typename OutputIterator>
+  void extractPeer(const BDE& peerData, OutputIterator dest)
+  {
+    if(peerData.isList()) {
+      extractPeerFromList(peerData, dest);
+    } else if(peerData.isString()) {
+      extractPeerFromCompact(peerData, dest);
+    }
+  }
 
-  virtual void extractPeer
-  (std::deque<SharedHandle<Peer> >& peers, const bencode::BDE& peerData) = 0;
+  template<typename OutputIterator>
+  void extractPeerFromList(const BDE& peerData, OutputIterator dest)
+  {
+    for(BDE::List::const_iterator itr = peerData.listBegin();
+        itr != peerData.listEnd(); ++itr) {
+      const BDE& peerDict = *itr;
+      if(!peerDict.isDict()) {
+        continue;
+      }
+      static const std::string IP = "ip";
+      static const std::string PORT = "port";
+      const BDE& ip = peerDict[IP];
+      const BDE& port = peerDict[PORT];
+      if(!ip.isString() || !port.isInteger() ||
+         !(0 < port.i() && port.i() < 65536)) {
+        continue;
+      }
+      *dest = SharedHandle<Peer>(new Peer(ip.s(), port.i()));
+      ++dest;
+    }
+  }
 
-  virtual bool canHandle(const bencode::BDE& peerData) const = 0;
+  template<typename OutputIterator>
+  void extractPeerFromCompact(const BDE& peerData, OutputIterator dest)
+  {
+    size_t length = peerData.s().size();
+    if(length%6 == 0) {
+      for(size_t i = 0; i < length; i += 6) {
+        struct in_addr in;
+        memcpy(&in.s_addr, peerData.s().c_str()+i, sizeof(uint32_t));
+        std::string ipaddr = inet_ntoa(in);
+        uint16_t port_nworder;
+        memcpy(&port_nworder, peerData.s().c_str()+i+4, sizeof(uint16_t));
+        uint16_t port = ntohs(port_nworder);
+        *dest = SharedHandle<Peer>(new Peer(ipaddr, port));
+        ++dest;
+      }
+    }
+  }
 };
 
-typedef SharedHandle<PeerListProcessor> PeerListProcessorHandle;
-
 } // namespace aria2
 
 #endif // _D_PEER_LIST_PROCESSOR_H_
