@@ -37,7 +37,6 @@
 #include <cassert>
 #include <algorithm>
 
-#include "BitfieldManFactory.h"
 #include "BitfieldMan.h"
 #include "A2STR.h"
 #include "BtMessageDispatcher.h"
@@ -52,11 +51,10 @@ PeerSessionResource::PeerSessionResource(size_t pieceLength, uint64_t totalLengt
   _chokingRequired(true),
   _optUnchoking(false),
   _snubbing(false),
-  _bitfieldMan(BitfieldManFactory::getFactoryInstance()->createBitfieldMan(pieceLength, totalLength)),
+  _bitfieldMan(new BitfieldMan(pieceLength, totalLength)),
   _fastExtensionEnabled(false),
   _extendedMessagingEnabled(false),
   _dhtEnabled(false),
-  _latency(DEFAULT_LATENCY),
   _lastDownloadUpdate(0),
   _lastAmUnchoking(0)
 {}
@@ -235,11 +233,6 @@ void PeerSessionResource::dhtEnabled(bool b)
   _dhtEnabled = b;
 }
 
-void PeerSessionResource::updateLatency(unsigned int latency)
-{
-  _latency = static_cast<unsigned int>(_latency*0.2+latency*0.8);
-}
-
 uint64_t PeerSessionResource::uploadLength() const
 {
   return _peerStat.getSessionUploadLength();
