@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -59,6 +59,7 @@
 #include "AnnounceTier.h"
 #include "DownloadContext.h"
 #include "bittorrent_helper.h"
+#include "a2functional.h"
 
 namespace aria2 {
 
@@ -81,7 +82,7 @@ bool TrackerWatcherCommand::execute() {
     if(_trackerRequestGroup.isNull()) {
       return true;
     } else if(_trackerRequestGroup->getNumCommand() == 0 ||
-	      _trackerRequestGroup->downloadFinished()) {
+              _trackerRequestGroup->downloadFinished()) {
       return true;
     } else {
       _trackerRequestGroup->setForceHaltRequested(true);
@@ -90,16 +91,26 @@ bool TrackerWatcherCommand::execute() {
     }
   }
   if(_btAnnounce->noMoreAnnounce()) {
-    logger->debug("no more announce");
+    if(logger->debug()) {
+      logger->debug("no more announce");
+    }
     return true;
   }
   if(_trackerRequestGroup.isNull()) {
     _trackerRequestGroup = createAnnounce();
     if(!_trackerRequestGroup.isNull()) {
       std::deque<Command*> commands;
-      _trackerRequestGroup->createInitialCommand(commands, e);
+      try {
+        _trackerRequestGroup->createInitialCommand(commands, e);
+      } catch(RecoverableException& ex) {
+        logger->error(EX_EXCEPTION_CAUGHT, ex);
+        std::for_each(commands.begin(), commands.end(), Deleter());
+        commands.clear();
+      }
       e->addCommand(commands);
-      logger->debug("added tracker request command");
+      if(logger->debug()) {
+        logger->debug("added tracker request command");
+      }
     }
   } else if(_trackerRequestGroup->downloadFinished()){
     try {
@@ -112,7 +123,7 @@ bool TrackerWatcherCommand::execute() {
       logger->error(EX_EXCEPTION_CAUGHT, ex);      
       _btAnnounce->announceFailure();
       if(_btAnnounce->isAllAnnounceFailed()) {
-	_btAnnounce->resetAnnounce();
+        _btAnnounce->resetAnnounce();
       }
     }
     _trackerRequestGroup.reset();
@@ -151,7 +162,7 @@ void TrackerWatcherCommand::processTrackerResponse
 {
   _btAnnounce->processAnnounceResponse
     (reinterpret_cast<const unsigned char*>(trackerResponse.c_str()),
-				      trackerResponse.size());
+     trackerResponse.size());
   while(!_btRuntime->isHalt() && _btRuntime->lessThanMinPeers()) {
     PeerHandle peer = _peerStorage->getUnusedPeer();
     if(peer.isNull()) {
@@ -164,7 +175,10 @@ void TrackerWatcherCommand::processTrackerResponse
     command->setPeerStorage(_peerStorage);
     command->setPieceStorage(_pieceStorage);
     e->commands.push_back(command);
-    logger->debug("CUID#%d - Adding new command CUID#%d", cuid, peer->usedBy());
+    if(logger->debug()) {
+      logger->debug("CUID#%d - Adding new command CUID#%d",
+                    cuid, peer->usedBy());
+    }
   }
 }
 
@@ -204,9 +218,13 @@ TrackerWatcherCommand::createRequestGroup(const std::string& uri)
   // If backup tracker is available, only try 2 times for each tracker
   // and if they all fails, then try next one.
   if(backupTrackerIsAvailable(_requestGroup->getDownloadContext())) {
-    logger->debug("This is multi-tracker announce.");
+    if(logger->debug()) {
+      logger->debug("This is multi-tracker announce.");
+    }
   } else {
-    logger->debug("This is single-tracker announce.");
+    if(logger->debug()) {
+      logger->debug("This is single-tracker announce.");
+    }
   }
   rg->getOption()->put(PREF_MAX_TRIES, "2");
   // TODO When dry-run mode becomes available in BitTorrent, set
@@ -216,8 +234,8 @@ TrackerWatcherCommand::createRequestGroup(const std::string& uri)
   static const std::string TRACKER_ANNOUNCE_FILE("[tracker.announce]");
   SharedHandle<DownloadContext> dctx
     (new DownloadContext(getOption()->getAsInt(PREF_SEGMENT_SIZE),
-			 0,
-			 TRACKER_ANNOUNCE_FILE));
+                         0,
+                         TRACKER_ANNOUNCE_FILE));
   dctx->setDir(A2STR::NIL);
   dctx->getFileEntries().front()->setUris(uris);
   rg->setDownloadContext(dctx);
