@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,6 +37,13 @@
 
 #include "XmlRpcMethod.h"
 
+#include <cassert>
+#include <deque>
+#include <algorithm>
+
+#include "BDE.h"
+#include "XmlRpcRequest.h"
+
 namespace aria2 {
 
 class DownloadResult;
@@ -160,9 +167,89 @@ public:
   }
 };
 
-class TellWaitingXmlRpcMethod:public XmlRpcMethod {
+template<typename T>
+class AbstractPaginationXmlRpcMethod:public XmlRpcMethod {
+private:
+  template<typename InputIterator>
+  std::pair<InputIterator, InputIterator>
+  getPaginationRange
+  (ssize_t offset, size_t num, InputIterator first, InputIterator last)
+  {
+    size_t size = std::distance(first, last);
+    if(offset < 0) {
+      ssize_t tempoffset = offset+size;
+      if(tempoffset < 0) {
+        return std::make_pair(last, last);
+      }
+      offset = tempoffset-(num-1);
+      if(offset < 0) {
+        offset = 0;
+        num = tempoffset+1;
+      }
+    } else if(size <= (size_t)offset) {
+      return std::make_pair(last, last);
+    }
+    BDE list = BDE::list();
+    size_t lastDistance;
+    if(size < offset+num) {
+      lastDistance = size;
+    } else {
+      lastDistance = offset+num;
+    }
+    last = first;
+    std::advance(first, offset);
+    std::advance(last, lastDistance);
+    return std::make_pair(first, last);
+  }
+
+  void checkPaginationParams(const BDE& params) const
+  {
+    assert(params.isList());
+    if(params.size() != 2 ||
+       !params[0].isInteger() || !params[1].isInteger() ||
+       params[1].i() < 0) {
+      throw DL_ABORT_EX("Invalid argument. Specify offset and num in integer.");
+    }
+  }
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e)
+  {
+    const BDE& params = req._params;
+    checkPaginationParams(params);
+    ssize_t offset = params[0].i();
+    size_t num = params[1].i();
+    const std::deque<SharedHandle<T> >& items = getItems(e);
+    std::pair<typename std::deque<SharedHandle<T> >::const_iterator,
+      typename std::deque<SharedHandle<T> >::const_iterator> range =
+      getPaginationRange(offset, num, items.begin(), items.end());
+    BDE list = BDE::list();
+    for(; range.first != range.second; ++range.first) {
+      BDE entryDict = BDE::dict();
+      createEntry(entryDict, *range.first, e);
+      list << entryDict;
+    }
+    if(offset < 0) {
+      std::reverse(list.listBegin(), list.listEnd());
+    }
+    return list;
+  }
+
+  virtual const std::deque<SharedHandle<T> >&
+  getItems(DownloadEngine* e) const = 0;
+
+  virtual void createEntry
+  (BDE& entryDict, const SharedHandle<T>& item, DownloadEngine* e) const = 0;
+};
+
+class TellWaitingXmlRpcMethod:
+    public AbstractPaginationXmlRpcMethod<RequestGroup> {
+protected:
+  virtual const std::deque<SharedHandle<RequestGroup> >&
+  getItems(DownloadEngine* e) const;
+
+  virtual void createEntry
+  (BDE& entryDict, const SharedHandle<RequestGroup>& item,
+   DownloadEngine* e) const;
 public:
   static const std::string& getMethodName()
   {
@@ -171,9 +258,15 @@ public:
   }
 };
 
-class TellStoppedXmlRpcMethod:public XmlRpcMethod {
+class TellStoppedXmlRpcMethod:
+    public AbstractPaginationXmlRpcMethod<DownloadResult> {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+   virtual const std::deque<SharedHandle<DownloadResult> >&
+   getItems(DownloadEngine* e) const;
+
+  virtual void createEntry
+  (BDE& entryDict, const SharedHandle<DownloadResult>& item,
+   DownloadEngine* e) const;
 public:
   static const std::string& getMethodName()
   {
@@ -248,6 +341,17 @@ public:
   }
 };
 
+class GetSessionInfoXmlRpcMethod:public XmlRpcMethod {
+protected:
+  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+public:
+  static const std::string& getMethodName()
+  {
+    static std::string methodName = "aria2.getSessionInfo";
+    return methodName;
+  }
+};
+
 class SystemMulticallXmlRpcMethod:public XmlRpcMethod {
 protected:
   virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
@@ -274,6 +378,12 @@ void gatherStoppedDownload
 void gatherProgressCommon
 (BDE& entryDict, const SharedHandle<RequestGroup>& group);
 
+#ifdef ENABLE_BITTORRENT
+// Helper function to store BitTorrent metadata from torrentAttrs in
+// btDict. btDict must be an BDE::Dict.
+void gatherBitTorrentMetadata(BDE& btDict, const BDE& torrentAttrs);
+#endif // ENABLE_BITTORRENT
+
 } // namespace xmlrpc
 
 } // namespace aria2
