@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -176,6 +176,8 @@ const std::string PREF_XML_RPC_LISTEN_ALL("xml-rpc-listen-all");
 const std::string PREF_INTERFACE("interface");
 // value: true | false
 const std::string PREF_DISABLE_IPV6("disable-ipv6");
+// value: true | false
+const std::string PREF_HUMAN_READABLE("human-readable");
 
 /**
  * FTP related preferences
@@ -222,6 +224,8 @@ const std::string PREF_CHECK_CERTIFICATE("check-certificate");
 const std::string PREF_USE_HEAD("use-head");
 // value: true | false
 const std::string PREF_HTTP_AUTH_CHALLENGE("http-auth-challenge");
+// value: true | false
+const std::string PREF_HTTP_NO_CACHE("http-no-cache");
 
 /** 
  * Proxy related preferences
@@ -310,6 +314,8 @@ const std::string PREF_BT_STOP_TIMEOUT("bt-stop-timeout");
 const std::string PREF_BT_PRIORITIZE_PIECE("bt-prioritize-piece");
 // values: true | false
 const std::string PREF_BT_SAVE_METADATA("bt-save-metadata");
+// values: true | false
+const std::string PREF_BT_METADATA_ONLY("bt-metadata-only");
 
 /**
  * Metalink related preferences
