@@ -1,8 +1,11 @@
 #include "BtSuggestPieceMessage.h"
-#include "PeerMessageUtil.h"
+
+#include <cstring>
 #include <cppunit/extensions/HelperMacros.h>
 
-using namespace std;
+#include "bittorrent_helper.h"
+
+namespace aria2 {
 
 class BtSuggestPieceMessageTest:public CppUnit::TestFixture {
 
@@ -27,16 +30,16 @@ CPPUNIT_TEST_SUITE_REGISTRATION(BtSuggestPieceMessageTest);
 
 void BtSuggestPieceMessageTest::testCreate() {
   unsigned char msg[9];
-  PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 5, 13);
-  PeerMessageUtil::setIntParam(&msg[5], 12345);
-  BtSuggestPieceMessageHandle pm = BtSuggestPieceMessage::create(&msg[4], 5);
-  CPPUNIT_ASSERT_EQUAL((int8_t)13, pm->getId());
-  CPPUNIT_ASSERT_EQUAL((int32_t)12345, pm->getIndex());
+  bittorrent::createPeerMessageString(msg, sizeof(msg), 5, 13);
+  bittorrent::setIntParam(&msg[5], 12345);
+  SharedHandle<BtSuggestPieceMessage> pm = BtSuggestPieceMessage::create(&msg[4], 5);
+  CPPUNIT_ASSERT_EQUAL((uint8_t)13, pm->getId());
+  CPPUNIT_ASSERT_EQUAL((size_t)12345, pm->getIndex());
 
   // case: payload size is wrong
   try {
     unsigned char msg[10];
-    PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 6, 13);
+    bittorrent::createPeerMessageString(msg, sizeof(msg), 6, 13);
     BtSuggestPieceMessage::create(&msg[4], 2);
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(...) {
@@ -44,7 +47,7 @@ void BtSuggestPieceMessageTest::testCreate() {
   // case: id is wrong
   try {
     unsigned char msg[9];
-    PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 5, 14);
+    bittorrent::createPeerMessageString(msg, sizeof(msg), 5, 14);
     BtSuggestPieceMessage::create(&msg[4], 1);
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(...) {
@@ -55,8 +58,8 @@ void BtSuggestPieceMessageTest::testGetMessage() {
   BtSuggestPieceMessage msg;
   msg.setIndex(12345);
   unsigned char data[9];
-  PeerMessageUtil::createPeerMessageString(data, sizeof(data), 5, 13);
-  PeerMessageUtil::setIntParam(&data[5], 12345);
+  bittorrent::createPeerMessageString(data, sizeof(data), 5, 13);
+  bittorrent::setIntParam(&data[5], 12345);
   CPPUNIT_ASSERT(memcmp(msg.getMessage(), data, 9) == 0);
 }
 
@@ -64,6 +67,8 @@ void BtSuggestPieceMessageTest::testToString() {
   BtSuggestPieceMessage msg;
   msg.setIndex(12345);
 
-  CPPUNIT_ASSERT_EQUAL(string("suggest piece index=12345"),
-		       msg.toString());
+  CPPUNIT_ASSERT_EQUAL(std::string("suggest piece index=12345"),
+                       msg.toString());
 }
+
+} // namespace aria2
