@@ -58,6 +58,9 @@ class UtilTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testGenerateRandomData);
   CPPUNIT_TEST(testFromHex);
   CPPUNIT_TEST(testParsePrioritizePieceRange);
+  CPPUNIT_TEST(testApplyDir);
+  CPPUNIT_TEST(testFixTaintedBasename);
+  CPPUNIT_TEST(testIsNumericHost);
   CPPUNIT_TEST_SUITE_END();
 private:
 
@@ -104,6 +107,9 @@ public:
   void testGenerateRandomData();
   void testFromHex();
   void testParsePrioritizePieceRange();
+  void testApplyDir();
+  void testFixTaintedBasename();
+  void testIsNumericHost();
 };
 
 
@@ -148,11 +154,11 @@ void UtilTest::testSplit() {
 }
 
 void UtilTest::testSplit_many() {
-  std::deque<std::string> v1;
+  std::vector<std::string> v1;
   util::split("name1=value1; name2=value2; name3=value3",std::back_inserter(v1),
-	      ";", true);
-  CPPUNIT_ASSERT_EQUAL(3, (int)v1.size());
-  std::deque<std::string>::iterator itr = v1.begin();
+              ";", true);
+  CPPUNIT_ASSERT_EQUAL((size_t)3, v1.size());
+  std::vector<std::string>::iterator itr = v1.begin();
   CPPUNIT_ASSERT_EQUAL(std::string("name1=value1"), *itr++);
   CPPUNIT_ASSERT_EQUAL(std::string("name2=value2"), *itr++);
   CPPUNIT_ASSERT_EQUAL(std::string("name3=value3"), *itr++);
@@ -160,12 +166,29 @@ void UtilTest::testSplit_many() {
   v1.clear();
 
   util::split("name1=value1; name2=value2; name3=value3",std::back_inserter(v1),
-	      ";", false);
-  CPPUNIT_ASSERT_EQUAL(3, (int)v1.size());
+              ";", false);
+  CPPUNIT_ASSERT_EQUAL((size_t)3, v1.size());
   itr = v1.begin();
   CPPUNIT_ASSERT_EQUAL(std::string("name1=value1"), *itr++);
   CPPUNIT_ASSERT_EQUAL(std::string(" name2=value2"), *itr++);
   CPPUNIT_ASSERT_EQUAL(std::string(" name3=value3"), *itr++);
+
+  v1.clear();
+
+  util::split("k=v", std::back_inserter(v1), ";", false, true);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, v1.size());
+  CPPUNIT_ASSERT_EQUAL(std::string("k=v"), v1[0]);
+
+  v1.clear();
+
+  util::split(" ", std::back_inserter(v1), ";", true, true);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, v1.size());
+  CPPUNIT_ASSERT_EQUAL(std::string(""), v1[0]);
+
+  v1.clear();
+
+  util::split(" ", std::back_inserter(v1), ";", true);
+  CPPUNIT_ASSERT_EQUAL((size_t)0, v1.size());
 }
 
 void UtilTest::testEndsWith() {
@@ -270,7 +293,8 @@ void UtilTest::testGetContentDispositionFilename() {
   CPPUNIT_ASSERT_EQUAL(std::string("aria2.tar.bz2"), util::getContentDispositionFilename(h8));
 
   std::string h9 = "attachment; filename=\"aria2.tar.bz2; creation-date=20 Jun 2007 00:00:00 GMT\"";
-  CPPUNIT_ASSERT_EQUAL(std::string("aria2.tar.bz2; creation-date=20 Jun 2007 00:00:00 GMT"), util::getContentDispositionFilename(h9));
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2.tar.bz2"),
+                       util::getContentDispositionFilename(h9));
 
   std::string h10 = "attachment; filename=";
   CPPUNIT_ASSERT_EQUAL(std::string(""), util::getContentDispositionFilename(h10));
@@ -280,15 +304,84 @@ void UtilTest::testGetContentDispositionFilename() {
 
   std::string filenameWithDir = "attachment; filename=dir/file";
   CPPUNIT_ASSERT_EQUAL(std::string("file"),
-		       util::getContentDispositionFilename(filenameWithDir));
+                       util::getContentDispositionFilename(filenameWithDir));
 
   std::string parentDir = "attachment; filename=..";
   CPPUNIT_ASSERT_EQUAL(std::string(),
-		       util::getContentDispositionFilename(parentDir));
+                       util::getContentDispositionFilename(parentDir));
 
   std::string currentDir = "attachment; filename=.";
   CPPUNIT_ASSERT_EQUAL(std::string(),
-		       util::getContentDispositionFilename(currentDir));
+                       util::getContentDispositionFilename(currentDir));
+  // RFC2231 Section4
+  std::string extparam2 = "filename*=''aria2";
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2"),
+                       util::getContentDispositionFilename(extparam2));
+  std::string extparam3 = "filename*='''";
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
+                       util::getContentDispositionFilename(extparam3));
+  std::string extparam4 = "filename*='aria2";
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
+                       util::getContentDispositionFilename(extparam4));
+  std::string extparam5 = "filename*='''aria2";
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
+                       util::getContentDispositionFilename(extparam5));
+  std::string extparam6 = "filename*";
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
+                       util::getContentDispositionFilename(extparam6));
+  std::string extparam7 = "filename*=UTF-8''aria2;filename=hello%20world";
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2"),
+                       util::getContentDispositionFilename(extparam7));
+  std::string extparam8 = "filename=aria2;filename*=UTF-8''hello%20world";
+  CPPUNIT_ASSERT_EQUAL(std::string("hello world"),
+                       util::getContentDispositionFilename(extparam8));
+  std::string extparam9 = "filename*=ISO-8859-1''%A3";
+  std::string extparam9ans;
+  extparam9ans += 0xc2;
+  extparam9ans += 0xa3;
+  CPPUNIT_ASSERT_EQUAL(extparam9ans,
+                       util::getContentDispositionFilename(extparam9));
+
+  // Tests from http://greenbytes.de/tech/tc2231/
+  // attwithasciifnescapedchar
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo.html"),
+     util::getContentDispositionFilename("filename=\"f\\oo.html\""));
+  // attwithasciifilenameucase
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo.html"),
+     util::getContentDispositionFilename("FILENAME=\"foo.html\""));
+  // attwithisofn2231iso
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo-ä.html"),
+     util::getContentDispositionFilename("filename*=iso-8859-1''foo-%E4.html"));
+  // attwithfn2231utf8
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo-ä-€.html"),
+     util::getContentDispositionFilename
+     ("filename*=UTF-8''foo-%c3%a4-%e2%82%ac.html"));
+  // attwithfn2231utf8-bad
+  CPPUNIT_ASSERT_EQUAL
+    (std::string(""),
+     util::getContentDispositionFilename
+     ("filename*=iso-8859-1''foo-%c3%a4-%e2%82%ac.html"));
+  // attwithfn2231ws1
+  CPPUNIT_ASSERT_EQUAL
+    (std::string(""),
+     util::getContentDispositionFilename("filename *=UTF-8''foo-%c3%a4.html"));
+  // attwithfn2231ws2
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo-ä.html"),
+     util::getContentDispositionFilename("filename*= UTF-8''foo-%c3%a4.html"));
+  // attwithfn2231ws3
+  CPPUNIT_ASSERT_EQUAL
+    (std::string("foo-ä.html"),
+     util::getContentDispositionFilename("filename* =UTF-8''foo-%c3%a4.html"));
+  // attwithfn2231quot
+  CPPUNIT_ASSERT_EQUAL
+    (std::string(""),
+     util::getContentDispositionFilename
+     ("filename*=\"UTF-8''foo-%c3%a4.html\""));
 }
 
 class Printer {
@@ -322,7 +415,7 @@ void UtilTest::testToLower() {
 void UtilTest::testUrldecode() {
   std::string src = "http://aria2.sourceforge.net/aria2%200.7.0%20docs.html";
   CPPUNIT_ASSERT_EQUAL(std::string("http://aria2.sourceforge.net/aria2 0.7.0 docs.html"),
-		       util::urldecode(src));
+                       util::urldecode(src));
 
   std::string src2 = "aria2+aria2";
   CPPUNIT_ASSERT_EQUAL(std::string("aria2+aria2"), util::urldecode(src2));
@@ -397,16 +490,16 @@ void UtilTest::testToStream()
   entries.push_back(f2);
   util::toStream(entries.begin(), entries.end(), os);
   CPPUNIT_ASSERT_EQUAL(
-		       std::string("Files:\n"
-			      "idx|path/length\n"
-			      "===+===========================================================================\n"
-			      "  1|aria2.tar.bz2\n"
-			      "   |12.0KiB (12,300)\n"
-			      "---+---------------------------------------------------------------------------\n"
-			      "  2|aria2.txt\n"
-			      "   |556B (556)\n"
-			      "---+---------------------------------------------------------------------------\n"),
-		       os.str());
+                       std::string("Files:\n"
+                                   "idx|path/length\n"
+                                   "===+===========================================================================\n"
+                                   "  1|aria2.tar.bz2\n"
+                                   "   |12.0KiB (12,300)\n"
+                                   "---+---------------------------------------------------------------------------\n"
+                                   "  2|aria2.txt\n"
+                                   "   |556B (556)\n"
+                                   "---+---------------------------------------------------------------------------\n"),
+                       os.str());
 }
 
 void UtilTest::testIsNumber()
@@ -480,8 +573,8 @@ void UtilTest::testConvertBitfield()
   util::convertBitfield(&destBitfield, &srcBitfield);
   
   CPPUNIT_ASSERT_EQUAL(std::string("9fffffffffffffffffffffffffffffff80"),
-		       util::toHex(destBitfield.getBitfield(),
-				   destBitfield.getBitfieldLength()));
+                       util::toHex(destBitfield.getBitfield(),
+                                   destBitfield.getBitfieldLength()));
 }
 
 void UtilTest::testParseIntRange()
@@ -593,7 +686,7 @@ void UtilTest::testParseLLInt()
 {
   CPPUNIT_ASSERT_EQUAL((int64_t)-1LL, util::parseLLInt(" -1 "));
   CPPUNIT_ASSERT_EQUAL((int64_t)9223372036854775807LL,
-		       util::parseLLInt("9223372036854775807"));
+                       util::parseLLInt("9223372036854775807"));
   try {
     util::parseLLInt("9223372036854775808");
     CPPUNIT_FAIL("exception must be thrown.");
@@ -623,7 +716,7 @@ void UtilTest::testParseLLInt()
 void UtilTest::testParseULLInt()
 {
   CPPUNIT_ASSERT_EQUAL((uint64_t)18446744073709551615ULL,
-		       util::parseULLInt("18446744073709551615"));
+                       util::parseULLInt("18446744073709551615"));
   try {
     util::parseUInt("-1");
     CPPUNIT_FAIL("exception must be thrown.");
@@ -726,7 +819,7 @@ void UtilTest::testUrlencode()
 void UtilTest::testHtmlEscape()
 {
   CPPUNIT_ASSERT_EQUAL(std::string("aria2&lt;&gt;&quot;&#39;util"),
-		       util::htmlEscape("aria2<>\"'util"));
+                       util::htmlEscape("aria2<>\"'util"));
 }
 
 void UtilTest::testJoinPath()
@@ -735,32 +828,32 @@ void UtilTest::testJoinPath()
   CPPUNIT_ASSERT_EQUAL
     (std::string("dir1/dir2/file"),
      util::joinPath(&dir1dir2file[0],
-		    &dir1dir2file[arrayLength(dir1dir2file)]));
+                    &dir1dir2file[arrayLength(dir1dir2file)]));
 
   const std::string dirparentfile[] = { "dir", "..", "file" };
   CPPUNIT_ASSERT_EQUAL
     (std::string("file"),
      util::joinPath(&dirparentfile[0],
-		    &dirparentfile[arrayLength(dirparentfile)]));
+                    &dirparentfile[arrayLength(dirparentfile)]));
 
   const std::string dirparentparentfile[] = { "dir", "..", "..", "file" };
   CPPUNIT_ASSERT_EQUAL
     (std::string("file"),
      util::joinPath(&dirparentparentfile[0],
-		    &dirparentparentfile[arrayLength(dirparentparentfile)]));
+                    &dirparentparentfile[arrayLength(dirparentparentfile)]));
 
   const std::string dirdotfile[] = { "dir", ".", "file" };
   CPPUNIT_ASSERT_EQUAL(std::string("dir/file"),
-		       util::joinPath(&dirdotfile[0],
-				      &dirdotfile[arrayLength(dirdotfile)]));
+                       util::joinPath(&dirdotfile[0],
+                                      &dirdotfile[arrayLength(dirdotfile)]));
 
   const std::string empty[] = {};
   CPPUNIT_ASSERT_EQUAL(std::string(""), util::joinPath(&empty[0], &empty[0]));
 
   const std::string parentdot[] = { "..", "." };
   CPPUNIT_ASSERT_EQUAL(std::string(""),
-		       util::joinPath(&parentdot[0],
-				      &parentdot[arrayLength(parentdot)]));
+                       util::joinPath(&parentdot[0],
+                                      &parentdot[arrayLength(parentdot)]));
 }
 
 void UtilTest::testParseIndexPath()
@@ -890,7 +983,7 @@ void UtilTest::testParsePrioritizePieceRange()
   CPPUNIT_ASSERT_EQUAL((size_t)6, result[3]);
   result.clear();
   util::parsePrioritizePieceRange(result, "head=300M,tail=300M",
-				  entries, pieceLength);
+                                  entries, pieceLength);
   CPPUNIT_ASSERT_EQUAL((size_t)7, result.size());
   for(size_t i = 0; i < 7; ++i) {
     CPPUNIT_ASSERT_EQUAL(i, result[i]);
@@ -900,4 +993,26 @@ void UtilTest::testParsePrioritizePieceRange()
   CPPUNIT_ASSERT(result.empty());
 }
 
+void UtilTest::testApplyDir()
+{
+  CPPUNIT_ASSERT_EQUAL(std::string("./pred"), util::applyDir("", "pred"));
+  CPPUNIT_ASSERT_EQUAL(std::string("/pred"), util::applyDir("/", "pred"));
+  CPPUNIT_ASSERT_EQUAL(std::string("./pred"), util::applyDir(".", "pred"));
+  CPPUNIT_ASSERT_EQUAL(std::string("/dl/pred"), util::applyDir("/dl", "pred"));
+}
+
+void UtilTest::testFixTaintedBasename()
+{
+  CPPUNIT_ASSERT_EQUAL(std::string("a_b"), util::fixTaintedBasename("a/b"));
+  CPPUNIT_ASSERT_EQUAL(std::string("a_b"), util::fixTaintedBasename("a\\b"));
+  CPPUNIT_ASSERT_EQUAL(std::string("a__b"), util::fixTaintedBasename("a\\/b"));
+}
+
+void UtilTest::testIsNumericHost()
+{
+  CPPUNIT_ASSERT(util::isNumericHost("192.168.0.1"));
+  CPPUNIT_ASSERT(!util::isNumericHost("aria2.sf.net"));
+  CPPUNIT_ASSERT(util::isNumericHost("::1"));
+}
+
 } // namespace aria2
